@@ -2,17 +2,31 @@
 #include <math.h>
 #include "matrix.h"
 	 
-void itfit(times,Ntimes,x,censcode,cause,KMc,z,n,px,Nit,betaS,
-score,hess,est,var,sim,antsim,rani,test,testOBS,Ut,simUt,weighted,
-gamma,vargamma,semi,zsem,pg,trans,gamma2,CA,line,detail,biid,gamiid,resample,
-timepow,clusters,antclust,timepowtest,silent,convc,weights,entry,trunkp,estimator,fixgamma,stratum,ordertime,
-conservative,ssf,KMtimes,gamscore,Dscore,monotone)
-double *times,*betaS,*x,*KMc,*z,*score,*hess,*est,*var,*test,*testOBS,
-*Ut,*simUt,*gamma,*zsem,*gamma2,*biid,*gamiid,*vargamma,*timepow,
-	*timepowtest,*convc,*weights,*entry,*trunkp,*ssf,*KMtimes,*gamscore,*Dscore;
-int *n,*px,*Ntimes,*Nit,*cause,*censcode,*sim,*antsim,*rani,*weighted,
-*semi,*pg,*trans,*CA,*line,*detail,*resample,*clusters,*antclust,*silent,*estimator,
-	*fixgamma,*stratum,*ordertime,*conservative,*monotone;
+void itfit(double *times,int *Ntimes,double *x,
+		int *censcode,int *cause,double *KMc,
+		double *z,int *n,int *px,
+		int *Nit,double *betaS, double *score,
+		double *hess,double *est,double *var,
+		int *sim,int *antsim,int *rani,
+		double *test,double *testOBS,double *Ut,
+		double *simUt,int *weighted, double *gamma,
+		double *vargamma,int *semi,double *zsem,
+		int *pg,int *trans,double *gamma2,
+		int *CA,int *line,int *detail,
+		double *biid,double *gamiid,int *resample,
+                double *timepow,int *clusters,int *antclust,
+		double *timepowtest,int *silent,double *convc,
+		double *weights,double *entry,double *trunkp,
+		int *estimator,int *fixgamma,int *stratum,
+		int *ordertime, int *conservative,double *ssf,
+		double *KMtimes,double *gamscore,double *Dscore,
+		int *monotone)
+//double *times,*betaS,*x,*KMc,*z,*score,*hess,*est,*var,*test,*testOBS,
+//*Ut,*simUt,*gamma,*zsem,*gamma2,*biid,*gamiid,*vargamma,*timepow,
+//	*timepowtest,*convc,*weights,*entry,*trunkp,*ssf,*KMtimes,*gamscore,*Dscore;
+//int *n,*px,*Ntimes,*Nit,*cause,*censcode,*sim,*antsim,*rani,*weighted,
+//*semi,*pg,*trans,*CA,*line,*detail,*resample,*clusters,*antclust,*silent,*estimator,
+//	*fixgamma,*stratum,*ordertime,*conservative,*monotone;
 { // {{
   // {{{ allocation and reading of data from R
   matrix *wX,*X,*cX,*A,*AI,*cumAt[*antclust],*VAR,*Z,*censX;
@@ -24,7 +38,7 @@ int *n,*px,*Ntimes,*Nit,*cause,*censcode,*sim,*antsim,*rani,*weighted,
 	 *vcudif=calloc((*Ntimes)*(*px+1),sizeof(double)),
 	 *cifentry=calloc((*n),sizeof(double)),
 	 *cumentry=calloc((*n)*(*px+1),sizeof(double));
-  float gasdev(),expdev(),ran1();
+//  float gasdev(),expdev(),ran1();
   ps=(*px); 
     // }}}
 
@@ -88,38 +102,45 @@ for (s=0;s<*Ntimes;s++)
       if (*trans==1) { // {{{
 	VE(pbhat,j)=1-exp(-VE(bhat,j));
 	varp=VE(pbhat,j)*(1-VE(pbhat,j)); 
+//        if (*monotone==1)  scl_vec_mult(1,xi,dp1); else  
 	scl_vec_mult(1-VE(pbhat,j),xi,dp);
       }
       if (*trans==2) {
 	VE(pbhat,j)=1-exp(-exp(VE(bhat,j))); 
 	varp=VE(pbhat,j)*(1-VE(pbhat,j)); 
+//        if (*monotone==1)  scl_vec_mult(1,xi,dp1); else  
 	scl_vec_mult((1-VE(pbhat,j))*exp(VE(bhat,j)),xi,dp); 
       }
       if (*trans==6) {
 	VE(pbhat,j)=1-exp(-VE(bhat,j)); 
 	varp=VE(pbhat,j)*(1-VE(pbhat,j)); 
+//        if (*monotone==1)  scl_vec_mult(1,xi,dp1); else  
 	scl_vec_mult((1-VE(pbhat,j)),xi,dp); 
       }
       if (*trans==3) {
 	    VE(pbhat,j)=exp(VE(bhat,j))/(1+exp(VE(bhat,j))); 
 	varp=VE(pbhat,j)*(1-VE(pbhat,j)); 
+//        if (*monotone==1)  scl_vec_mult(1,xi,dp1); else  
 	scl_vec_mult(exp(VE(bhat,j))/pow((1+exp(VE(bhat,j))),2),xi,dp);
       }
       if (*trans==7) {
 	    VE(pbhat,j)=VE(bhat,j)/(1+VE(bhat,j)); 
+//        if (*monotone==1)  scl_vec_mult(1,xi,dp1); else  
 	scl_vec_mult(1/pow((1+VE(bhat,j)),2),xi,dp);
       }
       if (*trans==4) {
          VE(pbhat,j)=exp(VE(bhat,j)); 
 	varp=VE(pbhat,j)*(1-VE(pbhat,j)); 
+//        if (*monotone==1)  scl_vec_mult(1,xi,dp1); else  
 	 scl_vec_mult(exp(VE(bhat,j)),xi,dp);
       }
       if (*trans==5) {
          VE(pbhat,j)=VE(bhat,j); 
-	varp=VE(pbhat,j)*(1-VE(pbhat,j)); 
+	 varp=VE(pbhat,j)*(1-VE(pbhat,j)); 
 	 scl_vec_mult(1,xi,dp);
       } // }}} 
-      scl_vec_mult(1,dp,dp1); 
+
+//      scl_vec_mult(1,dp,dp1); 
 
       if (*estimator<=2) scl_vec_mult(pow(weights[j],0.5),dp,dp); 
       else scl_vec_mult(pow(weights[j],0.5)*(time<KMc[j])*(time>entry[j]),dp,dp); 
@@ -171,11 +192,11 @@ for (s=0;s<*Ntimes;s++)
 	  print_mat(A); 
    }
    if (*stratum==1)  {
-      for (k=0;k<*px;k++) if (fabs(ME(A,k,k))<0.000001)  ME(AI,k,k)=0; else ME(AI,k,k)=1/ME(A,k,k);
+      for (k=0;k<*px;k++) ME(AI,k,k)=1/ME(A,k,k);
    }
 
 
-    if (( fabs(ME(AI,0,0))<.0000001) && (*stratum==0)) {
+    if (( ME(AI,0,0)==0) && (*stratum==0)) {
       convproblems=1; convt=0; silent[s]=1;
       for (c=0;c<ps;c++) VE(beta,c)=0; 
       for (c=0;c<*px;c++) VE(bet1,c)=betaS[c]; 
@@ -288,20 +309,20 @@ free(vcudif); free(cumentry); free(cifentry);
 } // }}}
 
 
-void itfitsemi(times,Ntimes,x,censcode,cause,
-	       KMc,z,antpers,px,Nit,
-	       score,hess,est,var,sim,
-	       antsim,rani,test,testOBS,Ut,
-	       simUt,weighted,gamma,vargamma,semi,
-	       zsem,pg,trans,gamma2,CA,
-	       line,detail,biid,gamiid,resample,
-	       timepow,clusters,antclust,timepowtest,silent,convc,weights,entry,trunkp,
-	       estimator,fixgamma,stratum,ordertime,conservative,ssf,KMtimes,
-	       gamscore,Dscore,monotone)
-double *times,*x,*KMc,*z,*score,*hess,*est,*var,*test,*testOBS,*Ut,*simUt,*gamma,*zsem,
-       *vargamma,*gamma2,*biid,*gamiid,*timepow,*timepowtest,*entry,*trunkp,*convc,*weights,*ssf,*KMtimes,*gamscore,*Dscore;
-int *antpers,*px,*Ntimes,*Nit,*cause,*censcode,*sim,*antsim,*rani,*weighted,*monotone,
-*semi,*pg,*trans,*CA,*line,*detail,*resample,*clusters,*antclust,*silent,*estimator,*fixgamma,*stratum,*ordertime,*conservative;
+void itfitsemi(double *times,int *Ntimes,double *x,int *censcode,int *cause,
+	       double *KMc,double *z,int *antpers,int *px,int *Nit,
+	       double *score,double *hess,double *est,double *var,int *sim,
+	       int *antsim,int *rani,double *test,double *testOBS,double *Ut,
+	       double *simUt,int *weighted,double *gamma,double *vargamma,int *semi,
+	       double *zsem,int *pg,int *trans,double *gamma2,int *CA,
+	       int *line,int *detail,double *biid,double *gamiid,int *resample,
+	       double *timepow,int *clusters,int *antclust,double *timepowtest,int *silent,double *convc,double *weights,double *entry,double *trunkp,
+	       int *estimator,int *fixgamma,int *stratum,int *ordertime,int *conservative,double *ssf,double *KMtimes,
+	       double *gamscore,double *Dscore,int *monotone)
+//double *times,*x,*KMc,*z,*score,*hess,*est,*var,*test,*testOBS,*Ut,*simUt,*gamma,*zsem,
+//       *vargamma,*gamma2,*biid,*gamiid,*timepow,*timepowtest,*entry,*trunkp,*convc,*weights,*ssf,*KMtimes,*gamscore,*Dscore;
+//int *antpers,*px,*Ntimes,*Nit,*cause,*censcode,*sim,*antsim,*rani,*weighted,*monotone,
+//*semi,*pg,*trans,*CA,*line,*detail,*resample,*clusters,*antclust,*silent,*estimator,*fixgamma,*stratum,*ordertime,*conservative;
 { // {{{
   // {{{ allocation and reading of data from R
   matrix *ldesignX,*A,*AI,*cdesignX,*ldesignG,*cdesignG,*censX,*censZ;
@@ -410,9 +431,9 @@ malloc_vec((*px)+(*pg),qs);
     extract_row(ldesignX,j,xi); extract_row(ldesignG,j,zi); 
     if (*estimator==2 && *monotone==1) {
          for(k=0;k<pmax;k++)   {
-		 if (k<*px)  ME(wX,j,k)= pow(weights[j]/KMtimes[s],0.5)*z[k*(*antpers)+j];
-		 if (k<*pg)  ME(wZ,j,k)= pow(weights[j]/KMtimes[s],0.5)*zsem[k*(*antpers)+j];
-	 }
+	 if (k<*px)  ME(wX,j,k)= pow(weights[j]/KMtimes[s],0.5)*z[k*(*antpers)+j];
+	 if (k<*pg)  ME(wZ,j,k)= pow(weights[j]/KMtimes[s],0.5)*zsem[k*(*antpers)+j];
+       }
     }
     lrr=0;  lrrt=0; 
     // {{{ compute P_1 and DP_1 
@@ -565,7 +586,7 @@ malloc_vec((*px)+(*pg),qs);
       varp=VE(plamt,j)*(1-VE(plamt,j)); 
       scl_vec_mult(VE(plamt,j),xi,dpx); 
       scl_vec_mult(VE(plamt,j),zi,dpz); 
-      if ((trunkp[j]<1)) { 
+      if ((trunkp[j]<1)) { /*{{{*/
 	 extract_row(ldesignG,j,zit); extract_row(ldesignX,j,xit); 
 	 for(i=1;i<=*px;i++) VE(truncbhatt,i-1)=cumentry[i*(*antpers)+j];
 	 for (l=0;l<*pg;l++) {
@@ -580,7 +601,7 @@ malloc_vec((*px)+(*pg),qs);
 	 scl_vec_mult(1/trunkp[j],dpx,dpx);
 	 scl_vec_mult(1/trunkp[j],dpz,dpz);  
 	 VE(plamt,j)=(VE(plamt,j)-phattrunc)/trunkp[j];
-      } 
+      } /*}}}*/
    } // }}} 
    if (*trans==5) { // relative risk, param 2 // {{{ 
       for (l=0;l<*pg;l++) { VE(zi,l)= pow(time,timepow[l])*VE(zi,l); 
@@ -591,7 +612,7 @@ malloc_vec((*px)+(*pg),qs);
       varp=VE(plamt,j)*(1-VE(plamt,j)); 
       scl_vec_mult(exp(lrr),xi,dpx); 
       scl_vec_mult(VE(plamt,j),zi,dpz); 
-      if ((trunkp[j]<1)) { 
+      if ((trunkp[j]<1)) { /*{{{*/
 	 extract_row(ldesignG,j,zit); extract_row(ldesignX,j,xit); 
 	 for(i=1;i<=*px;i++) VE(truncbhatt,i-1)=cumentry[i*(*antpers)+j];
 	 for (l=0;l<*pg;l++) { 
@@ -606,7 +627,7 @@ malloc_vec((*px)+(*pg),qs);
 		 scl_vec_mult(1/trunkp[j],dpx,dpx);
 		 scl_vec_mult(1/trunkp[j],dpz,dpz);  
 	 VE(plamt,j)=(VE(plamt,j)-phattrunc)/trunkp[j];
-      }
+      }/*}}}*/
    }  // }}} 
    if (*trans==8) { // log-relative risk, // {{{ 
       for (l=0;l<*pg;l++) { VE(zi,l)= pow(time,timepow[l])*VE(zi,l); 
@@ -679,16 +700,20 @@ malloc_vec((*px)+(*pg),qs);
        
   if (*monotone==0) MtM(cdesignX,A); else  MtA(cdesignX,ldesignX,A); 
 //  MtM(cdesignX,A); 
+  
+
   invertS(A,AI,osilent); sing=0; 
   if (ME(AI,0,0)==0 && (*stratum==0) && (osilent==0)) {
      Rprintf(" X'X not invertible at time %d %lf %d \n",s,time,osilent); 
      print_mat(A); 
   }
   if (*stratum==1)  {
-     for (k=0;k<*px;k++) if (fabs(ME(A,k,k))<0.000001)  ME(AI,k,k)=0; else ME(AI,k,k)=1/ME(A,k,k);
+//     for (k=0;k<*px;k++) if (fabs(ME(A,k,k))<0.000001)  ME(AI,k,k)=0; else ME(AI,k,k)=1/ME(A,k,k);
+     for (k=0;k<*px;k++) ME(AI,k,k)=1/ME(A,k,k);
   }
 
-  if ((fabs(ME(AI,0,0))<.00001) && ((*stratum==0) || ((*stratum==1) && (*px==1)))) {
+
+  if ((ME(AI,0,0)==0) && ((*stratum==0) || ((*stratum==1) && (*px==1))))   {
      convproblems=1;  silent[s]=1; 
      if (osilent==0) Rprintf("Iteration %d: non-invertible design at time %lf\n",itt,time); 
      for (k=1;k<=*px;k++) { inc[k*(*Ntimes)+s]=0; est[k*(*Ntimes)+s]=0; }
@@ -819,7 +844,7 @@ Rprintf("===========================================================\n");
 //	 score for gamma part of model 
 if (itt==(*Nit-1))  for (k=0;k<*pg;k++) gamscore[k]= VE(dgam,k); 
 
-} /*itt lkke */  // }}}
+} /*itt lokke */  // }}}
 	
 //head_matrix(cdesignX); head_matrix(wX); 
 
@@ -886,7 +911,7 @@ free(vcudif); free(inc); free(weightt); free(cifentry); free(cumentry);
 
 double mypow(double x,double p)
 {
-  double val,log(),exp(); 
+  double val; 
   val=exp(log(x)*p); 
   return(val); 
 }
