@@ -1,23 +1,26 @@
 #include <stdio.h>
 #include <math.h>
+#include <R.h>
 #include "matrix.h"
 #include <time.h>
 #include <sys/types.h>
                  
-void score(times,Ntimes,designX,nx,px,designG,ng,pg,antpers,start,stop,
-betaS,Nit,cu,vcu,w,mw,loglike,Iinv,Vbeta,detail,offs,mof,sim,antsim,
-Rvcu,RVbeta,
-test,testOBS,Ut,simUt,Uit,XligZ,aalen,nb,id,status,wscore,dNit,ratesim,score,dhatMit,gammaiid,dmgiid,
-retur,robust,covariance,Vcovs,addresamp,addproc,
-resample,gamiid,biid,clusters,antclust,vscore,betafixed,weights,entry,exactderiv,
-timegroup,maxtimepoint,stratum,silent,caseweight)
-double *designX,*designG,*times,*betaS,*start,*stop,*cu,*w,*loglike,*Vbeta,*RVbeta,*vcu,*offs,*Rvcu,*Iinv,*test,*testOBS,*Ut,*simUt,*Uit,*aalen,*score,*dhatMit,*gammaiid,*dmgiid,*Vcovs,*addproc,*gamiid,*biid,*vscore,*weights,*dNit,*sim,*caseweight;
-int*covariance,*nx,*px,*ng,*pg,*antpers,*Ntimes,*mw,*Nit,*detail,*mof,*antsim,*XligZ,*nb,*id,*status,*wscore,*ratesim,*retur,*robust,*addresamp,*resample,*clusters,*antclust,*betafixed,*entry,*exactderiv,*timegroup,*maxtimepoint,*stratum,*silent;
+void score(double *times,int *Ntimes,double *designX,int *nx,int *px,double *designG,int *ng,int *pg,int *antpers,double *start,double *stop,
+double *betaS,int *Nit,double *cu,double *vcu,double *w,int *mw,double *loglike,double *Iinv,double *Vbeta,int *detail,double *offs,int *mof,int *sim,int *antsim,
+double *Rvcu,double *RVbeta,
+double *test,double *testOBS,double *Ut,double *simUt,double *Uit,int *XligZ,double *aalen,int *nb,int *id,int *status,int *wscore,double *dNit,int *ratesim,double *score,double *dhatMit,double *gammaiid,double *dmgiid,
+int *retur,int *robust,int *covariance,double *Vcovs,int *addresamp,double *addproc,
+int *resample,double *gamiid,double *biid,int *clusters,int *antclust,double *vscore,int *betafixed,double *weights,int *entry,int *exactderiv,
+int *timegroup,int *maxtimepoint,int *stratum,double *silent,double *caseweight)
+//double *designX,*designG,*times,*betaS,*start,*stop,*cu,*w,*loglike,*Vbeta,*RVbeta,*vcu,*offs,*Rvcu,*Iinv,*test,*testOBS,*Ut,*simUt,*Uit,*aalen,*score,*dhatMit,*gammaiid,*dmgiid,*Vcovs,*addproc,*gamiid,*biid,*vscore,*weights,*dNit,*sim,*caseweight,*silent;
+//int*covariance,*nx,*px,*ng,*pg,*antpers,*Ntimes,*mw,*Nit,*detail,*mof,*antsim,*XligZ,*nb,*id,*status,*wscore,*ratesim,*retur,*robust,*addresamp,*resample,*clusters,*antclust,*betafixed,*entry,*exactderiv,*timegroup,*maxtimepoint,*stratum;
 { 
   int timing=0; 
   double basesim=0,basestart=0; 
-  int propodds=silent[1]; 
-  int icaseweight=silent[2]; 
+  int ssilent=round(silent[0]); 
+  double propodds=silent[1]; 
+  int icaseweight=round(silent[2]); 
+//  printf("%d %d  %lf \n",ssilent,icaseweight,propodds); 
   clock_t c0,c1; 
   c0=clock();
 //  mjump=sim[2];   // multiple jumps in clusters, relevant for ratesim=0 simulering via cholesky simulering 
@@ -58,8 +61,8 @@ int*covariance,*nx,*px,*ng,*pg,*antpers,*Ntimes,*mw,*Nit,*detail,*mof,*antsim,*X
          *timesg=calloc((*maxtimepoint),sizeof(double)),
          *powi=calloc(*Ntimes,sizeof(double)) ; 
 //         *caseweight=calloc(*Ntimes,sizeof(double)); 
-  double norm_rand();
-  void GetRNGstate(),PutRNGstate();
+//  double norm_rand();
+//  void GetRNGstate(),PutRNGstate();
 
   int stratpers=0,antstrat=stratum[1]; 
   double *S0strata=calloc(antstrat,sizeof(double)); 
@@ -220,7 +223,7 @@ int*covariance,*nx,*px,*ng,*pg,*antpers,*Ntimes,*mw,*Nit,*detail,*mof,*antsim,*X
 		S0+=RR*weights[c]; 
 		S0strata[stratum[c+2]]+=RR*weights[c]; 
                 for(j=0;j<pmax;j++) {
-	        if (j<*px) {ME(WX,id[c],j)=RR*designX[j*(*nx)+c];}
+	        if (j<*px) {ME(WX,id[c],j)=weights[c]*RR*designX[j*(*nx)+c];}
 	        if (j<*pg) {ME(WZ,id[c],j)=weights[c]*designG[j*(*ng)+c];} 
 		}
 		if (time==stop[c] && status[c]==1) {pers=id[c];stratpers=stratum[c+2];} 
@@ -255,7 +258,7 @@ int*covariance,*nx,*px,*ng,*pg,*antpers,*Ntimes,*mw,*Nit,*detail,*mof,*antsim,*X
 	    if (entry[ci]==1)  {
 	         replace_row(X,id[ci],xi); 
 		 replace_row(Z,id[ci],zi); 
-		 scl_vec_mult(RR,xi,tmpv1);
+		 scl_vec_mult(weights[ci]*RR,xi,tmpv1);
 		 replace_row(WX,id[ci],tmpv1);
 		 scl_vec_mult(weights[ci],zi,tmpv2);
 		 replace_row(WZ,id[ci],tmpv2); 
@@ -315,14 +318,14 @@ int*covariance,*nx,*px,*ng,*pg,*antpers,*Ntimes,*mw,*Nit,*detail,*mof,*antsim,*X
 	     print_mat(A);  print_mat(ZPZ); 
            }
 
-   if (stratum[0]==0)  invertS(A,AI,*silent); 
-   if (ME(AI,0,0)==0 && stratum[0]==0 && *silent==0) {
+   if (stratum[0]==0)  invertS(A,AI,ssilent); 
+   if (ME(AI,0,0)==0 && stratum[0]==0 && ssilent==0) {
       Rprintf("additive design X'X not invertible at time (number, value): %d %lf \n",s,time); print_mat(A);
    }
-   if (ME(AI,0,0)==0 && stratum[0]==0 && *silent==2) {
+   if (ME(AI,0,0)==0 && stratum[0]==0 && ssilent==2) {
       Rprintf("additive design X'X not invertible at time (number, value) : %d %lf \n",s,time); print_mat(A);
       Rprintf("print only first time with non-invertible design X'X\n"); 
-      silent[0]=0; 
+      ssilent=0; 
    }
 
    if (stratum[0]==1)  {
@@ -339,9 +342,9 @@ int*covariance,*nx,*px,*ng,*pg,*antpers,*Ntimes,*mw,*Nit,*detail,*mof,*antsim,*X
     MxA(ZX,AI,ZXAI); 
 //  if (*detail==3) {print_vec(xi); print_mat(A); print_mat(AI); }
 
-  if (propodds==1) {
+  if (propodds>0) { // intensity 1/(1+theta exp(Z^T beta) A(t-1))
           xdA=vec_prod(xi,cumm); 
-	  pweight=(1+exp(+VE(Gbeta,pers))*xdA);
+	  pweight=(1+propodds*exp(+VE(Gbeta,pers))*xdA);
 	  powi[s]=pweight; 
 	  scl_vec_mult(pweight,dA,dA); 
   }
@@ -362,13 +365,14 @@ int*covariance,*nx,*px,*ng,*pg,*antpers,*Ntimes,*mw,*Nit,*detail,*mof,*antsim,*X
 
   /* First derivative U and Second derivative S  */ 
   extract_row(Z,pers,zi);  
+  scl_vec_mult(scale,zi,zi); 
   Mv(ZX,dA,zav); 
 
 // pweight multiplied onto dA and therefore already on zav
-  if (propodds==1 || icaseweight==1) scl_vec_mult(pweight,zi,zi); 
+  if (propodds>0 || icaseweight==1) scl_vec_mult(pweight,zi,zi); 
   vec_subtr(zi,zav,difzzav); 
 //  scl_vec_mult(scale,difzzav,difzzav); 
-//  if (propodds==1 || icaseweight==1)   scl_vec_mult(pweight,difzzav,difzzav); 
+//  if (propodds>0 || icaseweight==1)   scl_vec_mult(pweight,difzzav,difzzav); 
 
   vec_add(difzzav,U,U); 
 
@@ -411,11 +415,11 @@ int*covariance,*nx,*px,*ng,*pg,*antpers,*Ntimes,*mw,*Nit,*detail,*mof,*antsim,*X
    MxA(ZXAI,ZPXo,tmp2); mat_subtr(ZPZo,tmp2, dS); 
 
   // also case-weights here
-//  if (propodds==1)   scl_mat_mult(pweight,dS,dS); 
+//  if (propodds>0)   scl_mat_mult(pweight,dS,dS); 
   if (icaseweight==1) scl_mat_mult(pweight,dS,dS); 
 
    // extra term for second derivative wrt beta  
-  if (propodds==1) {
+  if (propodds>0) {
 	  // (Z-E) Z exp(Z beta) x^T A(t-1)
 	  mat_add(dS,dSprop,dS); 
   }
@@ -478,7 +482,7 @@ int*covariance,*nx,*px,*ng,*pg,*antpers,*Ntimes,*mw,*Nit,*detail,*mof,*antsim,*X
   } // }}}
 
 
-  if (propodds==1) {
+  if (propodds>0) {
   // cumulative hazard (to use for prop odds model 
     vec_add(dA,cumm,cumm); 
   }
@@ -492,7 +496,7 @@ int*covariance,*nx,*px,*ng,*pg,*antpers,*Ntimes,*mw,*Nit,*detail,*mof,*antsim,*X
   } // }}}
 
 /* for (k=0;k<*pg;k++) ME(S1,k,k)=ME(S1,k,k)+*ridge;  */
-  invertS(S1,SI,*silent); 
+  invertS(S1,SI,ssilent); 
   if (*betafixed==0 )  {
       Mv(SI,U,delta); MxA(SI,VU,S2); MxA(S2,SI,VU); 
   }
@@ -568,7 +572,7 @@ int*covariance,*nx,*px,*ng,*pg,*antpers,*Ntimes,*mw,*Nit,*detail,*mof,*antsim,*X
 		S0+=RR*weights[c]; 
 	        S0strata[stratum[c+2]]+=RR*weights[c]; 
                 for(j=0;j<pmax;j++) {
-	        if (j<*px) {ME(WX,id[c],j)=RR*designX[j*(*nx)+c];}
+	        if (j<*px) {ME(WX,id[c],j)=weights[c]*RR*designX[j*(*nx)+c];}
 	        if (j<*pg) {ME(WZ,id[c],j)=weights[c]*designG[j*(*ng)+c];} 
 		}
 		if (time==stop[c] && status[c]==1) {pers=id[c];stratpers=stratum[c+2];} 
@@ -594,8 +598,8 @@ int*covariance,*nx,*px,*ng,*pg,*antpers,*Ntimes,*mw,*Nit,*detail,*mof,*antsim,*X
 	    if (entry[ci]==1)  {
 	         replace_row(X,id[ci],xi); 
 		 replace_row(Z,id[ci],zi); 
-//		 scl_vec_mult(RR*weights[ci],xi,tmpv1);
-		 scl_vec_mult(RR,xi,tmpv1);
+		 scl_vec_mult(RR*weights[ci],xi,tmpv1);
+//		 scl_vec_mult(RR,xi,tmpv1);
 		 replace_row(WX,id[ci],tmpv1);
 		 scl_vec_mult(weights[ci],zi,tmpv2);
 		 replace_row(WZ,id[ci],tmpv2); 
@@ -679,7 +683,7 @@ int*covariance,*nx,*px,*ng,*pg,*antpers,*Ntimes,*mw,*Nit,*detail,*mof,*antsim,*X
       Mv(ZXAI,xi,tmpv2);  
       vec_subtr(zi,tmpv2,tmpv2); 
       if (*mw==1) scl_vec_mult(VE(weight,pers),tmpv2,tmpv2); 
-      if (propodds==1 || icaseweight==1) scl_vec_mult(powi[s],tmpv2,tmpv2); 
+      if (propodds>0 || icaseweight==1) scl_vec_mult(powi[s],tmpv2,tmpv2); 
 
       vec_add(tmpv2,W2[cin],W2[cin]);
 
@@ -690,7 +694,7 @@ int*covariance,*nx,*px,*ng,*pg,*antpers,*Ntimes,*mw,*Nit,*detail,*mof,*antsim,*X
       if (basesim>=0) {
 	      Mv(AI,xi,rowX); 
 	      if (*mw==1) scl_vec_mult(VE(weight,pers),rowX,rowX); 
-              if (propodds==1 || icaseweight==1) scl_vec_mult(powi[s],rowX,rowX); 
+              if (propodds>0 || icaseweight==1) scl_vec_mult(powi[s],rowX,rowX); 
 	      vec_add(rowX,W3[cin],W3[cin]);
       }
 
@@ -726,13 +730,19 @@ int*covariance,*nx,*px,*ng,*pg,*antpers,*Ntimes,*mw,*Nit,*detail,*mof,*antsim,*X
          ME(M1M2t,j,i)=ME(M1M2n,j,(s-1)*(*px)+i);
          ME(Ct,i,j)= ME(Cn,(s-1)*(*px)+i,j);
     }
+//    printf(" s %d \n",s); 
+//    print_mat(Ct); 
 
     MxA(Ct,VU,tmp3); MAt(tmp3,Ct,CtVUCt);
+//    print_mat(CtVUCt); 
+
     MxA(Ct,SI,tmp3); MxA(tmp3,M1M2t,COV); 
+//    print_mat(COV); 
 
     for (k=1;k<=*px;k++) {
       if (*betafixed==0) 
 	vcu[k*(*Ntimes)+s]+=ME(CtVUCt,k-1,k-1)+2*ME(COV,k-1,k-1); 
+//	vcu[k*(*Ntimes)+s]+=ME(CtVUCt,k-1,k-1);
     }
     } // }}} 
 
@@ -952,7 +962,7 @@ int*covariance,*nx,*px,*ng,*pg,*antpers,*Ntimes,*mw,*Nit,*detail,*mof,*antsim,*X
     tau=times[*Ntimes-1]-times[0];
     for (i=1;i<=*px;i++) VE(rowX,i-1)=cug[i*(*maxtimepoint)+(*maxtimepoint-1)];
 
-    for (s=1;s<*maxtimepoint;s++)  // {{{ /* Beregning af OBS teststrrelser */
+    for (s=1;s<*maxtimepoint;s++)  // {{{ /* Beregning af OBS teststorrelser */
     {
       time=timesg[s]-times[0];  //  FIX 
 
@@ -984,7 +994,7 @@ int*covariance,*nx,*px,*ng,*pg,*antpers,*Ntimes,*mw,*Nit,*detail,*mof,*antsim,*X
 	else {vec_zeros(rowZ); replace_row(Utt,s,rowZ);}
       }
       for (k=1;k<=*pg;k++) Ut[k*(*maxtimepoint)+s]=ME(Utt,s,k-1);
-    }  // }}} *s=1..maxtimepoint Beregning af obs teststrrelser 
+    }  // }}} *s=1..maxtimepoint Beregning af obs teststorrelser 
 
   if (*detail==2)  Rprintf("Simulations start N= %ld \n",(long int) *antsim);
 
@@ -1116,7 +1126,7 @@ int*covariance,*nx,*px,*ng,*pg,*antpers,*Ntimes,*mw,*Nit,*detail,*mof,*antsim,*X
  
   if (timing==2) { // {{{
   c1=clock();
-  printf ("\telapsed CPU time: after freeing %f\n", (float) (c1 - c0)/CLOCKS_PER_SEC);
+  Rprintf ("\telapsed CPU time: after freeing %f\n", (float) (c1 - c0)/CLOCKS_PER_SEC);
   c0=clock();
   } // }}}
 
