@@ -2,12 +2,12 @@
 #include <math.h>
 #include "matrix.h"
                  
-void dynadd(times,y,Ntimes,designX,nx,px,designA,na,pa,ahat,bhat,bhatny,nxval,antpers,
-start,stop,cu0,cuf,cuMS,vcu0,vcuf,robvcu,w,mw,rani,sim,antsim,cumBit,test,
-testOBS,status,Ut,simUt,b,cumly,retur,id,smoothXX,weighted,vculy,clusters,antclust)
-double *bhatny,*bhat,*ahat,*designX,*designA,*times,*y,*start,*stop,*cu0,*cuf,*cuMS,
-*vcu0,*vcuf,*w,*robvcu,*cumBit,*test,*testOBS,*Ut,*simUt,*b,*cumly,*vculy;
-int *sim,*antsim,*retur,*nxval,*nx,*px,*na,*pa,*antpers,*Ntimes,*mw,*rani,*status,*id,*smoothXX,*weighted,*clusters,*antclust;
+void dynadd(double *times,double *y,int *Ntimes,double *designX,int *nx,int *px,double *designA,int *na,int *pa,double *ahat,double *bhat,double *bhatny,int *nxval,int *antpers,
+double *start,double *stop,double *cu0,double *cuf,double *cuMS,double *vcu0,double *vcuf,double *robvcu,double *w,int *mw,int *rani,int *sim,int *antsim,double *cumBit,double *test,
+double *testOBS,int *status,double *Ut,double *simUt,double *b,double *cumly,int *retur,int *id,int *smoothXX,int *weighted,double *vculy,int *clusters,int *antclust)
+//double *bhatny,*bhat,*ahat,*designX,*designA,*times,*y,*start,*stop,*cu0,*cuf,*cuMS,
+//*vcu0,*vcuf,*w,*robvcu,*cumBit,*test,*testOBS,*Ut,*simUt,*b,*cumly,*vculy;
+//int *sim,*antsim,*retur,*nxval,*nx,*px,*na,*pa,*antpers,*Ntimes,*mw,*rani,*status,*id,*smoothXX,*weighted,*clusters,*antclust;
 {
   matrix *ldesignX,*ldesignA,*cdesignX,*cdesignA,*Aa,*AaI,*A,*AI; 
   matrix *XbXa,*XWX;   
@@ -17,6 +17,7 @@ int *sim,*antsim,*retur,*nxval,*nx,*px,*na,*pa,*antpers,*Ntimes,*mw,*rani,*statu
   vector *dAt[*Ntimes];
   matrix *cumBt[*antpers];
   vector *cumhatB[*antpers],*cumB[*antpers],*cum;
+  int silent=1; 
   int pers=0,i,j,k,s,c,count,pmax,nmax,risk;
   int *coef=calloc(1,sizeof(int)),*imin=calloc(1,sizeof(int)),
       *ps=calloc(1,sizeof(int)),*degree=calloc(1,sizeof(int));
@@ -69,7 +70,7 @@ int *sim,*antsim,*retur,*nxval,*nx,*px,*na,*pa,*antpers,*Ntimes,*mw,*rani,*statu
 	    count=count+1;} 
 	}
 
-      MtA(ldesignA,ldesignA,Aa); invert(Aa,AaI);
+      MtA(ldesignA,ldesignA,Aa); invertS(Aa,AaI,silent);
       if (ME(AaI,0,0)==0.0) 
 	Rprintf("Dynadd: Aalen design not invertible at time %lf",time); 
       extract_row(ldesignA,pers,xai); 
@@ -88,7 +89,8 @@ int *sim,*antsim,*retur,*nxval,*nx,*px,*na,*pa,*antpers,*Ntimes,*mw,*rani,*statu
 	{scl_vec_mult(VE(pahat,j),extract_row(ldesignX,j,dB),dB);
 	  replace_row(cdesignX,j,dB); VE(pbahat,j)=VE(pbhat,j)*VE(pdA,j); } 
 
-      MtA(cdesignX,ldesignX,A); invert(A,AI);
+      MtA(cdesignX,ldesignX,A); 
+      invertS(A,AI,silent);
       if (ME(AI,0,0)==0.0) 
 	Rprintf("Dynadd: Regression design not invertible at time %lf",time); 
       extract_row(ldesignX,pers,tmpv); Mv(AI,tmpv,tmpv1); 
@@ -175,18 +177,17 @@ free(coef); free(ps); free(degree); free(imin);
 }
 
 
-void semidynadd(times,y,Ntimes,designX,nx,px,designG,ng,pg,designA,na,pa,
-ahat,naval,bhat,nxval,antpers,start,stop,cu0,cu,cums,robvcu,robvcue,
-gamma,gamma2,gamLY,gamKOR,gameffi,gameffims,
-Vgamma,Vkorgam,Vgamef,robvargam,robvargame,w,mw,rani,sim,antsim,
-mgresid,test,testOBS,Ut,simUt,b,id,status,weighted,vargamLY,clusters,antclust,resample,
-gammaiid,Biid)
-double *b,*bhat,*ahat,*designX,*designA,*designG,*times,*y,*start,*stop,*cu,*w,
-*gamLY,*gamKOR,*gamma,*gamma2,*gameffi,*gameffims,
-*Vgamma,*Vkorgam,*Vgamef,*robvargam,*robvargame,*vargamLY,
-*cums,*cu0,*robvcu,*robvcue,*Ut,*simUt,*test,*testOBS,*mgresid,*gammaiid,*Biid; 
-int *naval,*nxval,*nx,*px,*na,*pa,*ng,*pg,*antpers,*Ntimes,*mw,
-*sim,*antsim,*rani,*id,*status,*weighted,*clusters,*antclust,*resample;
+void semidynadd(double *times,double *y,int *Ntimes,double *designX,int *nx,int *px,double *designG,int *ng,int *pg,double *designA,int *na,int *pa,
+double *ahat,int *naval,double *bhat,int *nxval,int *antpers,double *start,double *stop,double *cu0,double *cu,double *cums,double *robvcu,double *robvcue,
+double *gamma,double *gamma2,double *gamLY,double *gamKOR,double *gameffi,double *gameffims,
+double *Vgamma,double *Vkorgam,double *Vgamef,double *robvargam,double *robvargame,double *w,int *mw,int *rani,int *sim,int *antsim,
+double *mgresid,double *test,double *testOBS,double *Ut,double *simUt,double *b,int *id,int *status,int *weighted,double *vargamLY,int *clusters,int *antclust,int *resample,double *gammaiid,double *Biid)
+//double *b,*bhat,*ahat,*designX,*designA,*designG,*times,*y,*start,*stop,*cu,*w,
+//*gamLY,*gamKOR,*gamma,*gamma2,*gameffi,*gameffims,
+//*Vgamma,*Vkorgam,*Vgamef,*robvargam,*robvargame,*vargamLY,
+//*cums,*cu0,*robvcu,*robvcue,*Ut,*simUt,*test,*testOBS,*mgresid,*gammaiid,*Biid; 
+//int *naval,*nxval,*nx,*px,*na,*pa,*ng,*pg,*antpers,*Ntimes,*mw,
+//*sim,*antsim,*rani,*id,*status,*weighted,*clusters,*antclust,*resample;
 {
   matrix *ldesignX,*ldesignA,*cdesignX,*ldesignG,*cdesignG,*A,*AI;
   matrix *dC,*Cg,*VarG,*dVarG,*VarGly,*dVarGly,*CI,*Vargam,*dCdt,*CGam,*dCGam,*Cgdt;
@@ -203,13 +204,13 @@ int *naval,*nxval,*nx,*px,*na,*pa,*ng,*pg,*antpers,*Ntimes,*mw,
   vector *tmpv,*tmpv1,*tmpv2,*tmpv3,*tmpv4,*zi,*xi,*ZHdp,*IZHdp,*IZHdN,*ZHdN;
   vector *korgamly,*korgam,*gamstart;
   vector *rowX,*rowZ,*difX,*dgamef,*gammsd,*ai; 
-  int l,i,j,k,s,c,count,pmax,nmax,pers=0;
+  int l,i,j,k,s,c,count,pmax,nmax,pers=0,silent=1;
   int robust=1,*ipers=calloc(*Ntimes,sizeof(int)), 
       *imin=calloc(1,sizeof(int)); 
   double time,dtime,zpers,risk,YoneN,dif,dif2,ctime;
   double *C=calloc((*pg)*(*pg),sizeof(double));
   double *vcudif=calloc((*Ntimes)*(*px+1),sizeof(double));
-  void comptest(); 
+//  void comptest(); 
   ctime=0;  
  
   malloc_mats(*antpers,*px,&ldesignX,&cdesignX,NULL);
@@ -281,7 +282,7 @@ int *naval,*nxval,*nx,*px,*na,*pa,*ng,*pg,*antpers,*Ntimes,*mw,
       Mv(ldesignG,gam,pghat);
       vec_add(pbhat,pghat,pbghat); 
 
-      MtA(ldesignA,ldesignA,A); invert(A,AI);
+      MtA(ldesignA,ldesignA,A); invertS(A,AI,silent);
       if (ME(AI,0,0)==0.0) 
 	Rprintf("Dynadd: Aalen design not invertible at time %lf\n",time); 
       extract_row(ldesignA,pers,ai); 
@@ -297,7 +298,7 @@ int *naval,*nxval,*nx,*px,*na,*pa,*ng,*pg,*antpers,*Ntimes,*mw,
 	replace_row(Zhat,j,zi);
 	VE(pbahat,j)=VE(pbghat,j)*VE(pdA,j);}/*sampling cor. design*/
 
-      MtA(ldesignX,cdesignX,XX); invert(XX,XXI); 
+      MtA(ldesignX,cdesignX,XX); invertS(XX,XXI,silent); 
       if (ME(XXI,0,0)==0.0) 
 	Rprintf("Dynadd: Regression design not invertible at time %lf\n",time); 
       MtA(ldesignG,ldesignX,ZX); MtA(cdesignG,ldesignX,cZX); 
@@ -393,7 +394,7 @@ int *naval,*nxval,*nx,*px,*na,*pa,*ng,*pg,*antpers,*Ntimes,*mw,
 
   R_CheckUserInterrupt();
   
-  invert(Cg,CI); 
+  invertS(Cg,CI,silent); 
   Mv(CI,IZHdp,gam);
   Mv(CI,gamly,korgamly);
   Mv(CI,gam2,gammsd); 
@@ -512,6 +513,5 @@ int *naval,*nxval,*nx,*px,*na,*pa,*ng,*pg,*antpers,*Ntimes,*mw,
 	      &korgamly,&korgam,&gamstart,
 	      &rowX,&rowZ,&difX,NULL); 
 
-  free(C); free(vcudif); free(ipers); 
-  free(imin); 
+  free(C); free(vcudif); free(ipers); free(imin); 
 }
