@@ -1,16 +1,17 @@
 #include <stdio.h>
 #include <math.h>
+#include <R.h>
 #include "matrix.h"
 #include <time.h>
 #include <sys/types.h>
                  
-void posubdist2(times,Ntimes,designX,nx,px,antpers,start,stop,betaS,Nit,cu,vcu,Iinv,
-Vbeta,detail,sim,antsim,rani,Rvcu,RVbeta,test,testOBS,Ut,simUt,Uit,id,status,
-weighted,ratesim,score,dhatMit,dhatMitiid,retur,loglike,profile,sym,
-KMtimes,KMti,etime,causeS,ipers,baselinevar,clusters,antclust,ccode,biid,gamiid,wweights)
-double *designX,*times,*betaS,*start,*stop,*cu,*Vbeta,*RVbeta,*vcu,*Rvcu,*Iinv,*test,*testOBS,*Ut,*simUt,*Uit,*score,*dhatMit,*dhatMitiid,*loglike,
-       *KMtimes,*KMti,*etime,*biid,*gamiid,*wweights;
-int *nx,*px,*antpers,*Ntimes,*Nit,*detail,*sim,*antsim,*rani,*id,*status,*weighted,*ratesim,*retur,*profile,*sym,*causeS,*ipers,*baselinevar,*clusters,*antclust,*ccode; 
+void posubdist2(double *times,int *Ntimes,double *designX,int *nx,int *px,int *antpers,double *start,double *stop,double *betaS,int *Nit,double *cu,double *vcu,double *Iinv,
+double *Vbeta,int *detail,int *sim,int *antsim,int *rani,double *Rvcu,double *RVbeta,double *test,double *testOBS,double *Ut,double *simUt,double *Uit,int *id,int *status,
+int *weighted,int *ratesim,double *score,double *dhatMit,double *dhatMitiid,int *retur,double *loglike,int *profile,int *sym,
+double *KMtimes,double *KMti,double *etime,int *causeS,int *ipers,int *baselinevar,int *clusters,int *antclust,int *ccode,double *biid,double *gamiid,double *wweights)
+//double *designX,*times,*betaS,*start,*stop,*cu,*Vbeta,*RVbeta,*vcu,*Rvcu,*Iinv,*test,*testOBS,*Ut,*simUt,*Uit,*score,*dhatMit,*dhatMitiid,*loglike,
+//       *KMtimes,*KMti,*etime,*biid,*gamiid,*wweights;
+//int *nx,*px,*antpers,*Ntimes,*Nit,*detail,*sim,*antsim,*rani,*id,*status,*weighted,*ratesim,*retur,*profile,*sym,*causeS,*ipers,*baselinevar,*clusters,*antclust,*ccode; 
 {
 // {{{  setting up
   matrix *ldesignX,*WX,*ldesignG,*CtVUCt,*A,*AI;
@@ -32,8 +33,8 @@ int *nx,*px,*antpers,*Ntimes,*Nit,*detail,*sim,*antsim,*rani,*id,*status,*weight
   int *pg=calloc(1,sizeof(int)),c,robust=1,pers=0,ci,i,j,k,l,s,it;
   double weights,risks,RR,S0star,time,alpha,ll;
   double S0,tau,random,scale,sumscore;
-  double norm_rand();
-  void GetRNGstate(),PutRNGstate();
+//  double norm_rand();
+//  void GetRNGstate(),PutRNGstate();
 
   pg[0]=1; 
 
@@ -307,7 +308,7 @@ int *nx,*px,*antpers,*Ntimes,*Nit,*detail,*sim,*antsim,*rani,*id,*status,*weight
       }; // }}} 
 
       // updating beta 
-      vec_add(beta,delta,beta); 
+if (it<(*Nit-1))  vec_add(beta,delta,beta); 
 
       for (k=0;k<*px;k++) sumscore= sumscore+
 	(*profile==1)*fabs(VE(Upl,k))+(*profile==0)*fabs(VE(U,k));  
@@ -329,6 +330,7 @@ int *nx,*px,*antpers,*Ntimes,*Nit,*detail,*sim,*antsim,*rani,*id,*status,*weight
 
 //  if (*baselinevar==1) 
     vec_zeros(xi);dummy=0;  
+  if (robust==1) 
   for (s=*Ntimes-1;s>0;s--) { // {{{ /* computation of q(t) =============   */ 
       extract_row(gt,s,dA); 
       scl_vec_mult(exp(-VE(lht,s))*VE(incS0t,s),dA,dA); 
@@ -565,7 +567,7 @@ int *nx,*px,*antpers,*Ntimes,*Nit,*detail,*sim,*antsim,*rani,*id,*status,*weight
     tau=times[*Ntimes-1]-times[0];
     for (i=1;i<=*pg;i++) VE(rowZ,i-1)=cu[i*(*Ntimes)+(*Ntimes-1)];
 
-    /* Beregning af OBS teststrrelser */
+    /* Beregning af OBS teststorrelser */
     for (s=1;s<*Ntimes;s++) { time=times[s]-times[0]; 
 
       for (i=1;i<=*pg;i++) {
@@ -587,7 +589,7 @@ int *nx,*px,*antpers,*Ntimes,*Nit,*detail,*sim,*antsim,*rani,*id,*status,*weight
 	else {vec_zeros(rowX); replace_row(Utt,s,rowX);}
       }
       for (k=1;k<=*px;k++) Ut[k*(*Ntimes)+s]=ME(Utt,s,k-1);
-    } /*s=1..Ntimes Beregning af obs teststrrelser */
+    } /*s=1..Ntimes Beregning af obs teststorrelser */
 
 
     for (k=1;k<=*antsim;k++) {
